@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 
-from pyg_cell._cell import cell, cell_go, cell_item, cell_func, cell_load, cell_output, cell_clear, cell_inputs
+from pyg_cell._cell import cell, updated_cell, cell_go, cell_item, cell_func, cell_load, cell_output, cell_clear, cell_inputs
 from pyg_cell._dag import get_DAG, get_DAGs, get_GADs, get_GAD, add_edge, topological_sort, descendants, del_edge
 from pyg_cell._acell import acell, acell_load, acell_func, acell_go
 from pyg_cell._db_cell import db_cell, db_load, db_save, get_cell, get_data, load_cell, load_data, cell_push, cell_pull
